@@ -18,7 +18,7 @@
 // along with this program ; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 //
-// $Id: Federation.cc,v 3.45 2005/04/30 16:41:27 breholee Exp $
+// $Id: Federation.cc,v 3.45.2.1 2007/01/22 13:54:51 rousse Exp $
 // ----------------------------------------------------------------------------
 
 #include <config.h>
@@ -424,7 +424,7 @@ void
 Federation::broadcastInteraction(FederateHandle federate_handle,
                                  InteractionClassHandle interaction,
                                  ParameterHandle *parameter_handles,
-                                 ParameterValue *parameter_values,
+                                 ParameterLengthPair *parameter_values,
                                  UShort list_size,
                                  FederationTime time,
 				 RegionHandle region_handle,
@@ -1136,7 +1136,7 @@ void
 Federation::updateAttributeValues(FederateHandle federate,
                                   ObjectHandle id,
                                   AttributeHandle *attributes,
-                                  AttributeValue *values,
+                                  ValueLengthPair *values,
                                   UShort list_size,
                                   FederationTime time,
                                   const char *tag)
@@ -1757,5 +1757,5 @@ Federation::saveXmlData()
 
 }} // namespace certi/rtig
 
-// $Id: Federation.cc,v 3.45 2005/04/30 16:41:27 breholee Exp $
+// $Id: Federation.cc,v 3.45.2.1 2007/01/22 13:54:51 rousse Exp $
 
