@@ -18,7 +18,7 @@
 // along with this program ; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 //
-// $Id: FederationsList.cc,v 3.29 2005/04/30 16:41:28 breholee Exp $
+// $Id: FederationsList.cc,v 3.29.2.1 2007/01/22 13:54:51 rousse Exp $
 // ----------------------------------------------------------------------------
 
 #include <config.h>
@@ -365,7 +365,7 @@ FederationsList::updateAttribute(Handle handle,
                                  FederateHandle federate,
                                  ObjectHandle id,
                                  AttributeHandle *attributes,
-                                 AttributeValue *values,
+                                 ValueLengthPair *values,
                                  UShort list_size,
                                  FederationTime time,
                                  const char *tag)
@@ -398,7 +398,7 @@ FederationsList::updateParameter(Handle handle,
                                  FederateHandle federate,
                                  InteractionClassHandle interaction,
                                  ParameterHandle *parameters,
-                                 ParameterValue *values,
+                                 ParameterLengthPair *values,
                                  UShort list_size,
                                  FederationTime time,
 				 RegionHandle region,
@@ -1264,5 +1264,5 @@ FederationsList::federateRestoreStatus(Handle the_federation,
 
 }} // certi::rtig
 
-// EOF $Id: FederationsList.cc,v 3.29 2005/04/30 16:41:28 breholee Exp $
+// EOF $Id: FederationsList.cc,v 3.29.2.1 2007/01/22 13:54:51 rousse Exp $
 
