@@ -1,15 +1,13 @@
 // ----------------------------------------------------------------------------
 // CERTI - HLA RunTime Infrastructure
-// Copyright (C) 2002, 2003  ONERA
+// Copyright (C) 2002-2005  ONERA
 //
-// This file is part of CERTI-libCERTI
-//
-// CERTI-libCERTI is free softwarE ; you can redistribute it and/or
+// This program is free software ; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public License
 // as published by the Free Software Foundation ; either version 2 of
 // the License, or (at your option) any later version.
 //
-// CERTI-libCERTI is distributed in the hope that it will be useful, but
+// This program is distributed in the hope that it will be useful, but
 // WITHOUT ANY WARRANTY ; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 // Lesser General Public License for more details.
@@ -19,7 +17,7 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 // USA
 //
-// $Id: SecureTCPSocket.cc,v 3.5 2003/06/27 17:26:29 breholee Exp $
+// $Id: SecureTCPSocket.cc,v 3.7 2005/05/16 18:41:06 breholee Exp $
 // ----------------------------------------------------------------------------
 
 #include <config.h>
@@ -33,18 +31,15 @@
 
 namespace certi {
 
-static pdCDebug D("STCPSOCK", "(s-TCPsok) - ");
-
-// ----------------------
-// -- SecureTCPSocket --
-// ----------------------
+static pdCDebug D("STCPSOCK", __FILE__);
 
+// ----------------------------------------------------------------------------
 SecureTCPSocket::SecureTCPSocket()
     : SocketTCP()
 {
 #ifdef WITH_GSSAPI
-    SessionInitialized = RTI_FALSE ;
-    DecryptedMessageReady = RTI_FALSE ;
+    SessionInitialized = false ;
+    DecryptedMessageReady = false ;
 
     GSSHandler = new GSSAPIHandler();
 
@@ -56,11 +51,7 @@ SecureTCPSocket::SecureTCPSocket()
     PeerName = NULL ;
 }
 
-
-// ----------------------
-// -- SecureTCPSocket --
-// ----------------------
-
+// ----------------------------------------------------------------------------
 SecureTCPSocket::~SecureTCPSocket()
 {
     if (PeerName != NULL) {
@@ -74,44 +65,31 @@ SecureTCPSocket::~SecureTCPSocket()
 #endif // WITH_GSSAPI
 }
 
-
-// -------------
-// -- Emettre --
-// -------------
-
+// ----------------------------------------------------------------------------
 void
-SecureTCPSocket::send(void *Buffer, unsigned long Size)
+SecureTCPSocket::send(const unsigned char *buffer, size_t size)
     throw (NetworkError, NetworkSignal)
 {
     D.Out(pdTrace, "SSocket: Sending.");
 
 #ifdef HLA_USES_GSSAPI
-
     // If the GSSAPI session is not Initialized, start the HandShake.
-
-    if (SessionInitialized == RTI_FALSE)
+    if (!SessionInitialized)
         sendInitialToken();
 
     // Send Message
-
-    sendMessage(Buffer, Size);
-
+    sendMessage(buffer, size);
 #else
-
-    SocketTCP::send(Buffer, Size);
-
+    SocketTCP::send(buffer, size);
 #endif
 }
 
 #ifdef WITH_GSSAPI
-
-// ----------------
-// -- GetMessage --
-// ----------------
-
-void SecureTCPSocket::getMessage()
+// ----------------------------------------------------------------------------
+void
+SecureTCPSocket::getMessage()
 {
-    if (DecryptedMessageReady == RTI_TRUE) {
+    if (DecryptedMessageReady) {
         D.Out(pdExcept, "Decrypted message already exists.");
         return ;
     }
@@ -125,15 +103,11 @@ void SecureTCPSocket::getMessage()
 
     GSSHandler->getMessage((SocketTCP *)this, &IncomingBuffer);
 
-    DecryptedMessageReady = RTI_TRUE ;
+    DecryptedMessageReady = true ;
 }
-
 #endif // WITH_GSSAPI
 
-// --------------
-// -- GetClass --
-// --------------
-
+// ----------------------------------------------------------------------------
 int
 SecureTCPSocket::getClass() const
 {
@@ -145,14 +119,11 @@ SecureTCPSocket::getClass() const
 }
 
 #ifdef WITH_GSSAPI
-
-// --------------------
-// -- GetMessagePart --
-// --------------------
-
-void SecureTCPSocket::getMessagePart(void *Buffer, unsigned long Size)
+// ----------------------------------------------------------------------------
+void
+SecureTCPSocket::getMessagePart(void *Buffer, unsigned long Size)
 {
-    if (DecryptedMessageReady == RTI_FALSE)
+    if (!DecryptedMessageReady)
         getMessage();
 
     // Check available size
@@ -173,16 +144,12 @@ void SecureTCPSocket::getMessagePart(void *Buffer, unsigned long Size)
     if (CurrentOffset >= IncomingBuffer.length) {
         GSSHandler->releaseBuffer(&IncomingBuffer);
         CurrentOffset = 0 ;
-        DecryptedMessageReady = RTI_FALSE ;
+        DecryptedMessageReady = false ;
     }
 }
-
 #endif // WITH_GSSAPI
 
-// -----------------
-// -- GetPeerName --
-// -----------------
-
+// ----------------------------------------------------------------------------
 const char *
 SecureTCPSocket::getPeerName()
 {
@@ -199,11 +166,7 @@ SecureTCPSocket::getPeerName()
     throw RTIinternalError("No peer's principal name.");
 }
 
-
-// --------------
-// -- Recevoir --
-// --------------
-
+// ----------------------------------------------------------------------------
 void
 SecureTCPSocket::receive(void *Buffer, unsigned long Size)
     throw (NetworkError, NetworkSignal)
@@ -214,7 +177,7 @@ SecureTCPSocket::receive(void *Buffer, unsigned long Size)
 
     // If the GSSAPI session is not Initialized, start the HandShake.
 
-    if (SessionInitialized == RTI_FALSE)
+    if (!SessionInitialized)
         receiveInitialToken();
 
     getMessagePart(Buffer, Size);
@@ -229,12 +192,9 @@ SecureTCPSocket::receive(void *Buffer, unsigned long Size)
 }
 
 #ifdef WITH_GSSAPI
-
-// ----------------------
-// -- RecvInitialToken --
-// ----------------------
-
-void SecureTCPSocket::receiveInitialToken()
+// ----------------------------------------------------------------------------
+void
+SecureTCPSocket::receiveInitialToken()
 {
     D.Out(pdInit, "Receiving Initial Token.");
 
@@ -248,15 +208,12 @@ void SecureTCPSocket::receiveInitialToken()
 
     D.Out(pdInit, "GSSAPI session initialized.");
 
-    SessionInitialized = RTI_TRUE ;
+    SessionInitialized = true ;
 }
 
-
-// ----------------------
-// -- SendInitialToken --
-// ----------------------
-
-void SecureTCPSocket::sendInitialToken()
+// ----------------------------------------------------------------------------
+void
+SecureTCPSocket::sendInitialToken()
 {
     uid_t CurrentUID ;
     struct passwd *PasswdEntry ;
@@ -283,15 +240,12 @@ void SecureTCPSocket::sendInitialToken()
 
     D.Out(pdInit, "GSSAPI session initialized.");
 
-    SessionInitialized = RTI_TRUE ;
+    SessionInitialized = true ;
 }
 
-
-// -----------------
-// -- SendMessage --
-// -----------------
-
-void SecureTCPSocket::sendMessage(void *Buffer, unsigned long Size)
+// ----------------------------------------------------------------------------
+void
+SecureTCPSocket::sendMessage(void *Buffer, unsigned long Size)
 {
     gss_buffer_desc OutputToken ;
 
@@ -300,9 +254,8 @@ void SecureTCPSocket::sendMessage(void *Buffer, unsigned long Size)
 
     GSSHandler->sendMessage((SocketTCP *)this, &OutputToken);
 }
-
 #endif // WITH_GSSAPI
 
 }
 
-// $Id: SecureTCPSocket.cc,v 3.5 2003/06/27 17:26:29 breholee Exp $
+// $Id: SecureTCPSocket.cc,v 3.7 2005/05/16 18:41:06 breholee Exp $
