@@ -188,7 +188,7 @@ typedef int YYSTYPE;
 
 
 /* Line 216 of yacc.c.  */
-#line 192 "y.tab.c"
+#line 192 "syntax.cc"
 
 #ifdef short
 # undef short
@@ -1603,7 +1603,7 @@ yyreduce:
 
 
 /* Line 1267 of yacc.c.  */
-#line 1607 "y.tab.c"
+#line 1607 "syntax.cc"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
