@@ -1,7 +1,26 @@
-// $Id: graph_c.cc,v 3.0.2.1 2002/11/22 00:52:57 breholee Exp $ 
+// ---------------------------------------------------------------------------
+// libgraphc - X11 drawing library
+// Copyright (C) 2002, 2003  ONERA
+//
+// This library is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public License as
+// published by the Free Software Foundation; either version 2 of the
+// License, or (at your option) any later version.
+//
+// This library is distributed in the hope that it will be useful, but
+// WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+// General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software
+// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+// USA
+//
+// $Id: graph_c.cc,v 3.4 2003/11/12 14:37:15 breholee Exp $ 
 // ---------------------------------------------------------------------------
 
-#ifdef WITH_X11
+#ifndef X_DISPLAY_MISSING
 
 #include <config.h>
 
@@ -2187,6 +2206,6 @@ void ModeNORMAL()
 	XSetFunction(canal_aff,contexte_graph,GXcopy);
 }
 
-#endif // WITH_X11
+#endif // X_DISPLAY_MISSING
 
-// $Id: graph_c.cc,v 3.0.2.1 2002/11/22 00:52:57 breholee Exp $
+// $Id: graph_c.cc,v 3.4 2003/11/12 14:37:15 breholee Exp $
